@@ -1,5 +1,5 @@
 package Zapp;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Plan building, job creating web app
 
 #pod =head1 SYNOPSIS
@@ -266,6 +266,9 @@ sub get_plan( $self, $plan_id ) {
             if ( my $config = $input->{config} ) {
                 $input->{config} = decode_json( $config );
             }
+            if ( my $value = $input->{value} ) {
+                $input->{value} = decode_json( $value );
+            }
         }
     }
     return $plan;
@@ -543,7 +546,7 @@ Zapp - Plan building, job creating web app
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -612,12 +615,6 @@ L<Yancy>, L<Mojolicious>
 
 Doug Bell <preaction@cpan.org>
 
-=head1 CONTRIBUTOR
-
-=for stopwords Doug Bell
-
-Doug Bell <doug.bell@grantstreet.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2020 by Doug Bell.
