@@ -302,8 +302,6 @@ $colors{256} = {
 
 sub ansi_colorize( $text ) {
     my @parts = split /\e\[([\d;]*)m/, $text;
-    ; use Data::Dumper;
-    ; say Dumper \@parts;
     return $parts[0] if @parts == 1;
     my $output = shift @parts;
     my %context;
@@ -395,7 +393,7 @@ Zapp::Util - General utilities for Zapp
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SUBROUTINES
 
